stm32-metapac

Crates

git

Versions

stm32u5g9vj

Flavors

Icr

Struct Icr 

#[repr(transparent)]
pub struct Icr(pub u32);
OTFDEC interrupt clear register.

Tuple Fields

0: u32

Implementations



impl Icr

pub const fn seif(&self) -> bool

Security error interrupt flag clear This bit is written by application, and always read as 0.

pub const fn set_seif(&mut self, val: bool)

Security error interrupt flag clear This bit is written by application, and always read as 0.

pub const fn xoneif(&self) -> bool

Execute-only execute-never error interrupt flag clear This bit is written by application, and always read as 0.

pub const fn set_xoneif(&mut self, val: bool)

Execute-only execute-never error interrupt flag clear This bit is written by application, and always read as 0.

pub const fn keif(&self) -> bool

Key error interrupt flag clear This bit is written by application, and always read as 0. Note: Clearing KEIF does not solve the source of the problem (bad key registers). To be able to access again any encrypted region, OTFDEC key registers must be properly initialized again.

pub const fn set_keif(&mut self, val: bool)

Key error interrupt flag clear This bit is written by application, and always read as 0. Note: Clearing KEIF does not solve the source of the problem (bad key registers). To be able to access again any encrypted region, OTFDEC key registers must be properly initialized again.